#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 28/09/2018

import vmpsys    as sys
import vmputils  as utils
import vmpconfig as config

config.pyenv()

import vmp

help_=[("Vampiria python main:","dirmain(directory path main),id(id process),debug(bool),input(dictionary)")]

if __name__ == "__main__":
  args=sys.argv_get()
  if (len(args) == 4):  
     input_=sys.isdict(args[3])
     if input_ is not None:
       if args[2] == "True":  
         vmp.init(args[1],True)
       else:
         vmp.init(args[1],False)
       try:
         vmp.input_=input_
         sys.append(args[0])
         main=sys.main_def()
         main()
       except Exception as e:
         vmp.exit_failure(str(e)) 
       vmp.exit_ok()
  utils.help('vmpmain.py',help_)
  
